searchData={"content_type":"text/markdown","items":[{"doc":"Module for working with \"result\" tuples. Provides helpers for wrapping,\nunwrapping, and transforming result tuples.\n\nAn opinionated stance on what constitutes a \"result\" tuple is taken here. A\nresult tuple is a tuple of the form `{:ok, value}` or `{:error, value}` and\nNOTHING else.\n\nThese helpers are most useful in pipelines.","ref":"ExResult.html","title":"ExResult","type":"module"},{"doc":"","ref":"ExResult.html#error/1","title":"ExResult.error/1","type":"function"},{"doc":"Helper function to check if a value is an `:error` tuple. Useful in pipelines\nwhere you want to check if a value is an `:error` tuple.\n\n#","ref":"ExResult.html#error?/1","title":"ExResult.error?/1","type":"function"},{"doc":"iex> error?({:ok, 1})\n    false\n\n    iex> error?({:error, :foo})\n    true\n\n    iex> error?(1)\n    false","ref":"ExResult.html#error?/1-examples","title":"Examples - ExResult.error?/1","type":"function"},{"doc":"Guard to check if a value is a result tuple. A result tuple is a tuple of the\nform `{:ok, value}` or `{:error, value}` and NOTHING else.\n\n#","ref":"ExResult.html#is_result/1","title":"ExResult.is_result/1","type":"macro"},{"doc":"iex> is_result({:ok, 1})\n    true\n\n    iex> is_result({:error, :foo})\n    true\n\n    iex> is_result(1)\n    false","ref":"ExResult.html#is_result/1-examples","title":"Examples - ExResult.is_result/1","type":"macro"},{"doc":"Helper function to wrap a value in an `:ok` tuple. Useful in pipelines where\nyou want to wrap a value in an `:ok` tuple. If the value is already an `:ok`\ntuple, it will be returned as-is.\n\n#","ref":"ExResult.html#ok/1","title":"ExResult.ok/1","type":"function"},{"doc":"iex> ok(1)\n    {:ok, 1}\n\n    iex> ok({:ok, 1})\n    {:ok, 1}","ref":"ExResult.html#ok/1-examples","title":"Examples - ExResult.ok/1","type":"function"},{"doc":"Helper function to check if a value is an `:ok` tuple. Useful in pipelines\nwhere you want to check if a value is an `:ok` tuple.\n\n#","ref":"ExResult.html#ok?/1","title":"ExResult.ok?/1","type":"function"},{"doc":"iex> ok?({:ok, 1})\n    true\n\n    iex> ok?({:error, :foo})\n    false\n\n    iex> ok?(1)\n    false","ref":"ExResult.html#ok?/1-examples","title":"Examples - ExResult.ok?/1","type":"function"},{"doc":"Helper function to unwrap the value from an `:ok` tuple, or to return an\n`:error` tuple as-is. If the value is not an `:ok` or `:error` tuple, an\nerror will be raised. Useful in pipelines where you want to unwrap an `:ok`\ntuple, but pass an `:error` tuple through.\n\n#","ref":"ExResult.html#unwrap/1","title":"ExResult.unwrap/1","type":"function"},{"doc":"iex> unwrap({:ok, 1})\n    1\n\n    iex> unwrap({:error, :foo})\n    {:error, :foo}\n\n    iex> unwrap(1)\n    ** (RuntimeError) Not an ok tuple","ref":"ExResult.html#unwrap/1-examples","title":"Examples - ExResult.unwrap/1","type":"function"},{"doc":"Helper function to uwrap the value from an `:ok` tuple, or to raise an error\nif it is not an `:ok` tuple. Useful in pipelines where you want to modify an\nOK result, but raise an error if it is not an OK tuple.\n\n#","ref":"ExResult.html#unwrap!/1","title":"ExResult.unwrap!/1","type":"function"},{"doc":"iex> unwrap!({:ok, 1})\n    1\n\n    iex> unwrap!({:error, :foo})\n    ** (RuntimeError) Not an ok tuple\n\n    iex> unwrap!(1)\n    ** (RuntimeError) Not an ok tuple","ref":"ExResult.html#unwrap!/1-examples","title":"Examples - ExResult.unwrap!/1","type":"function"},{"doc":"Helper function to unwrap the value from an `:ok` tuple and execute a\ntransform on it, or to return an `:error` tuple as-is. If the value is not an\n`:ok` or `:error` tuple, an error will be raised. Useful in pipelines where\nyou want to unwrap and transform an `:ok` tuple value, but pass an `:error`\ntuple through.\n\n#","ref":"ExResult.html#unwrap_and_update/2","title":"ExResult.unwrap_and_update/2","type":"function"},{"doc":"iex> unwrap_and_update({:ok, 1}, &(&1 * 2))\n    2\n\n    iex> unwrap_and_update({:error, :foo}, &(&1 * 2))\n    {:error, :foo}\n\n    iex> unwrap_and_update(1, &(&1 * 2))\n    ** (RuntimeError) Not an ok tuple","ref":"ExResult.html#unwrap_and_update/2-examples","title":"Examples - ExResult.unwrap_and_update/2","type":"function"},{"doc":"Helper function to execute a transform on the value of an `:ok` tuple, or to\nraise an error if it is not an `:ok` tuple. Useful in pipelines where you\nwant to modify an OK result, but raise an error if it is not an OK tuple.\n\n#","ref":"ExResult.html#unwrap_and_update!/2","title":"ExResult.unwrap_and_update!/2","type":"function"},{"doc":"iex> unwrap_and_update!({:ok, 1}, &(&1 * 2))\n    2\n\n    iex> unwrap_and_update!({:error, :foo}, &(&1 * 2))\n    ** (RuntimeError) Not an ok tuple\n\n    iex> unwrap_and_update!(1, &(&1 * 2))\n    ** (RuntimeError) Not an ok tuple","ref":"ExResult.html#unwrap_and_update!/2-examples","title":"Examples - ExResult.unwrap_and_update!/2","type":"function"},{"doc":"Helper function to update the value of an `:ok` tuple, or to return an :error\ntuple as-is. If the value is not an `:ok` or `:error` tuple, an error will be\nraised. Useful in pipelines where you want to modify an OK result, but pass an\nerror through.\n\n#","ref":"ExResult.html#update/2","title":"ExResult.update/2","type":"function"},{"doc":"iex> update({:ok, 1}, &(&1 + 1))\n    {:ok, 2}\n\n    iex> update({:error, :foo}, &(&1 + 1))\n    {:error, :foo}\n\n    iex> update(1, &(&1 + 1))\n    ** (RuntimeError) Not an ok or error tuple","ref":"ExResult.html#update/2-examples","title":"Examples - ExResult.update/2","type":"function"},{"doc":"Helper function to update the value of an `:ok` tuple, or to raise an error\nif it is not an `:ok` tuple. Useful in pipelines where you want to modify an\nOK result, but raise an error if it is not an OK tuple.\n\n#","ref":"ExResult.html#update!/2","title":"ExResult.update!/2","type":"function"},{"doc":"iex> update!({:ok, 1}, &(&1 + 1))\n    {:ok, 2}\n\n    iex> update!({:error, :foo}, &(&1 + 1))\n    ** (RuntimeError) Not an ok tuple\n\n    iex> update!(1, &(&1 + 1))\n    ** (RuntimeError) Not an ok tuple","ref":"ExResult.html#update!/2-examples","title":"Examples - ExResult.update!/2","type":"function"}]}